# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from openstack import resource


class LoadBalancerStatus(resource.Resource):

    base_path = '/elb/loadbalancers/%(loadbalancer_id)s/statuses'

    # capabilities
    allow_fetch = True
    allow_list = True

    # Properties
    loadbalancer_id = resource.URI('loadbalancer_id')

    #: Status of Load Balancer
    statuses = resource.Body('statuses')
